﻿
using System;
using System.Collections.Generic;
using Autodesk.Revit.DB;

namespace StairsAutomation
{
	/// <summary>
	/// Description of LandingConfigurationUtils.
	/// </summary>
	public class LandingConfigurationUtils
	{
		public static IList<Curve> ProjectCurvesToElevation(IList<Curve> curves, double elevation)
		{
			List<Curve> ret = new List<Curve>();
			foreach (Curve curve in curves)
			{
				ret.Add(ProjectCurveToElevation(curve, elevation));
			}
			return ret;
		}
		
		public static Curve ProjectCurveToElevation(Curve curve, double elevation)
		{
			double offset1 = elevation - curve.get_EndPoint(0).Z;
            Curve projectedCurve = curve.get_Transformed(Transform.get_Translation(new XYZ(0, 0, offset1)));
            return projectedCurve;
		}
		
		public static Line FindLongestEndpointConnection(Line line1, Line line2)
        {
            double maxDistance = 0.0;
            XYZ endPoint1 = null;
            XYZ endPoint2 = null;

            for (int i = 0; i < 2; i++)
            {
                for (int j = 0; j < 2; j++)
                {
                    double distance = line1.get_EndPoint(j).DistanceTo(line2.get_EndPoint(i));
                    if (distance > maxDistance)
                    {
                        maxDistance = distance;
                        endPoint1 = line1.get_EndPoint(j);
                        endPoint2 = line2.get_EndPoint(i);
                    }
                }
            }

            return Line.get_Bound(endPoint1, endPoint2);
        }
		
		public static double ComputeParameter(Curve curve, XYZ point)
		{
			IntersectionResult result = curve.Project(point);
			return result.Parameter;
		}
	}
}
