﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Autodesk.Revit.DB;

namespace StairsAutomation
{
    class StairsRectangleLandingConfiguration : IStairsLandingConfiguration
    {
        public StairsRectangleLandingConfiguration(Line stairsRunBoundary1, Line stairsRunBoundary2, XYZ runDirection, double elevation, double width)
        {
            // offset to base elevation
            m_stairsRunBoundary1 = LandingConfigurationUtils.ProjectCurveToElevation(stairsRunBoundary1, elevation) as Line;
            m_stairsRunBoundary2 = LandingConfigurationUtils.ProjectCurveToElevation(stairsRunBoundary2, elevation) as Line;

            m_runDirection = runDirection;
            m_width = width;
            m_elevation = elevation;
        }

        private Line m_stairsRunBoundary1;
        private Line m_stairsRunBoundary2;
        private XYZ m_runDirection;
        private double m_width;
        private double m_elevation;

        #region IStairsLandingConfiguration Members

        public Autodesk.Revit.DB.CurveLoop GetLandingBoundary()
        {
            Line boundaryLine = LandingConfigurationUtils.FindLongestEndpointConnection(m_stairsRunBoundary1, m_stairsRunBoundary2);
    
            // offset by 1/2 of width
            Curve centerCurve = boundaryLine.get_Transformed(Transform.get_Translation(m_runDirection * (m_width/ 2.0)));

            // Create by Thicken
            CurveLoop curveLoop = CurveLoop.CreateViaThicken(centerCurve, m_width, XYZ.BasisZ);

            return curveLoop;
        }

        public double GetLandingBaseElevation()
        {
            return m_elevation;
        }

        #endregion
    }
}
