﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Autodesk.Revit.DB;

namespace StairsAutomation
{
    public class StairsTransformedRunConfiguration : IStairsRunConfiguration
    {
        #region IStairsRunConfiguration Members

        public double GetRunElevation()
        {
            return m_configuration.GetRunElevation(); 
        }

        public IList<Autodesk.Revit.DB.Curve> GetRunStairsPath()
        {
            return TransformCurves(m_configuration.GetRunStairsPath());
        }

        public IList<Autodesk.Revit.DB.Curve> GetRunRiserCurves()
        {
            return TransformCurves(m_configuration.GetRunRiserCurves());
        }

        public IList<Autodesk.Revit.DB.Curve> GetRunBoundaryCurves()
        {
            return TransformCurves(m_configuration.GetRunBoundaryCurves());
        }

        #endregion

        public StairsTransformedRunConfiguration(IStairsRunConfiguration configuration, Transform transform)
        {
            m_transform = transform;
            m_configuration = configuration;
        }

        private Transform m_transform;
        private IStairsRunConfiguration m_configuration;

        private IList<Curve> TransformCurves(IList<Curve> inputs)
        {
            int numCurves = inputs.Count;

            for (int i = 0; i < numCurves; i++)
            {
                Curve trfCurve = inputs[i].get_Transformed(m_transform);
                inputs[i] = trfCurve;
            }
            return inputs;
        }
    }
}
