﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Autodesk.Revit.UI;
using Autodesk.Revit.UI.Selection;
using Autodesk.Revit.DB;

namespace StairsAutomation
{
    [Autodesk.Revit.Attributes.Transaction(Autodesk.Revit.Attributes.TransactionMode.Manual)]
    public class StairsAutomationCommand : IExternalCommand
    {
        #region IExternalCommand Members

        public Result Execute(ExternalCommandData commandData, ref string message, Autodesk.Revit.DB.ElementSet elements)
        {
            UIDocument activeDocument = commandData.Application.ActiveUIDocument;
            Document document = activeDocument.Document;
            StairsAutomationUtility utility =  StairsAutomationUtility.Create(document, s_stairNumber);

            utility.GenerateStairs();

            s_stairNumber++;
            if (s_stairNumber > 5)
                s_stairNumber = 0;

            return Result.Succeeded;
        }

        #endregion

        private static int s_stairNumber = 0;  

        class CurveElementSelectionFilter : ISelectionFilter
        {
            #region ISelectionFilter Members

            public bool AllowElement(Element elem)
            {
                return elem is ModelCurve;
            }

            public bool AllowReference(Reference reference, XYZ position)
            {
                return true;
            }

            #endregion
        }
    }


}
