﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Autodesk.Revit.DB;
using Autodesk.Revit.DB.Architecture;

namespace StairsAutomation
{
    public class StairsSingleStraightRun : IStairsConfiguration
    {
        IStairsRunConfiguration m_runConfiguration;

        public StairsSingleStraightRun(Stairs stairs, Level bottomLevel)
        {
            StairsType stairsType = stairs.Document.GetElement(stairs.GetTypeId()) as StairsType;
            this.m_runConfiguration = new StraightStairsRunConfiguration(stairs.DesiredRisersNumber, bottomLevel.Elevation, stairsType.MinTreadDepth, stairsType.MinRunWidth);
        }

        public StairsSingleStraightRun(Stairs stairs, Level bottomLevel, Transform transform)
        {
            StairsType stairsType = stairs.Document.GetElement(stairs.GetTypeId()) as StairsType;
            IStairsRunConfiguration baseConfiguration = new StraightStairsRunConfiguration(stairs.DesiredRisersNumber, bottomLevel.Elevation, stairsType.MinTreadDepth, stairsType.MinRunWidth);
            m_runConfiguration = new StairsTransformedRunConfiguration(baseConfiguration, transform);
        }

        #region IStairsConfiguration Members

        public int GetNumberOfRuns()
        {
            return 1;
        }

        public double GetRunElevation(int index)
        {
            if (index != 0)
                throw new ArgumentOutOfRangeException("index", "Invalid index");

            return m_runConfiguration.GetRunElevation();
        }

        public IList<Curve> GetRunStairsPath(int index)
        {
            if (index != 0)
                throw new ArgumentOutOfRangeException("index", "Invalid index");

            return m_runConfiguration.GetRunStairsPath();
        }

        public IList<Curve> GetRunRiserCurves(int index)
        {
            if (index != 0)
                throw new ArgumentOutOfRangeException("index", "Invalid index");

            return m_runConfiguration.GetRunRiserCurves();
        }

        public IList<Curve> GetRunBoundaryCurves(int index)
        {
            if (index != 0)
                throw new ArgumentOutOfRangeException("index", "Invalid index");

            return m_runConfiguration.GetRunBoundaryCurves();
        }

        public int GetNumberOfLandings()
        {
            return 0;
        }

        public CurveLoop GetLandingBoundary(int index)
        {
            return null;
        }

        public double GetLandingBaseElevation(int index)
        {
            return 0.0;
        }

        #endregion
    }
}
